##1) Load Packages ####

#install/import packages needed
library('tidyverse')
library('magrittr')


#2) Set WD and read reps####

setwd("YOUR DIR - NOTE AS SUPERFOLDER ABOVE OTHER FOLDERS IN THE ZIP!")
getwd()

#Read replicates and only use proteins with >= 2 unique peptides 
CDM_1_st <- read_tsv("./data/20180216_JB_01_Proteins.txt") %>% 
  filter(`# Unique Peptides` >= 2) %>%
  separate(Description, c("Name", "Species", "Gene_Symbol_PE", "A", "B"), sep = "=", remove = FALSE) %>% 
  separate(Gene_Symbol_PE, c("Gene_name", "PE"), sep = "\\s") %>%
  select(Accession, Gene_name, Name, Description, X..Unique.Peptides = `# Unique Peptides`) %>%
  mutate(Master = paste0(Accession, "_", Gene_name))

CDM_2_st <- read_tsv("./data/20180216_JB_03_Proteins.txt") %>% 
  filter(`# Unique Peptides` >= 2) %>%
  separate(Description, c("Name", "Species", "Gene_Symbol_PE", "A", "B"), sep = "=", remove = FALSE) %>% 
  separate(Gene_Symbol_PE, c("Gene_name", "PE"), sep = "\\s") %>%
  select(Accession, Gene_name, Name, Description, X..Unique.Peptides = `# Unique Peptides`) %>%
  mutate(Master = paste0(Accession, "_", Gene_name))

CDM_3_st <- read_tsv("./data/20180320_JB_01_Proteins.txt") %>% 
  filter(`# Unique Peptides` >= 2) %>%
  separate(Description, c("Name", "Species", "Gene_Symbol_PE", "A", "B"), sep = "=", remove = FALSE) %>% 
  separate(Gene_Symbol_PE, c("Gene_name", "PE"), sep = "\\s") %>%
  select(Accession, Gene_name, Name, Description, X..Unique.Peptides = `# Unique Peptides`) %>%
  mutate(Master = paste0(Accession, "_", Gene_name))


#Join tables together 

CDM_1_2 <- full_join(CDM_1_st, CDM_2_st, by = "Master", suffix = c("_R1", "_R2"))
CDM_master <- full_join(CDM_1_2, CDM_3_st, by = "Master")

CDM_master <- CDM_master  %>% select(Gene_name_R1, Gene_name_R2, Gene_name_R3 = Gene_name, Accession_R1, Accession_R2, Accession_R3 = Accession, Master) %>% 
  separate(Master, c("Accession", "Gene_name"), sep = "_")

write.csv(CDM_master, file = "./output/HPDE_Consensus_CDM_master.csv", row.names = FALSE)

#Load Matrisome file 
Matrisome <- read.csv("./databases/matrisome_hs_masterlist.csv", sep = ",", header = TRUE) %>% select(Gene_name = Gene.Symbol, Division, Category)


#A) Create consensus CDM
CDM_annotated <- merge(CDM_master, Matrisome, by = "Gene_name")

#B) Get integrins and then merge with CDM_annotated -> For this use the UIshort (derived from the UniqueIntegrins file 
#Load Interactions from Bader Lab
Interactions <- read.table("./databases/BaderLab_ECM_Rec_Interactions.txt", sep = "\t", header = TRUE)

#Extract all interactions starting with an integrin in col A and then sort for those that don't have an empty interaction type
IntIntsA <- Interactions[grepl("ITG", Interactions$..AliasA),] %>% 
  separate(confidence, c("HPR", "LPR", "NP"), sep = "\\|", remove = FALSE) %>% 
  select(..AliasA, AliasB, HPR, interactionType, pmids) %>%
  filter(pmids != "-") %>%
  distinct() %>%
  drop_na() %>%
  select(A = '..AliasA', B = 'AliasB')
  
IntIntsB <- Interactions[grepl("ITG", Interactions$AliasB),] %>% 
  separate(confidence, c("HPR", "LPR", "NP"), sep = "\\|") %>% 
  select(..AliasA, AliasB, HPR, interactionType, pmids) %>% 
  filter(pmids != "-") %>%
  distinct() %>%
  drop_na() %>%
  select(A = 'AliasB', B = '..AliasA',)


#Convert names of columns and combine A and B
IntInts <- rbind(IntIntsA, IntIntsB)
IntInts <- unique(IntInts[c("A", "B")])

#Get Unique integrins from the IntInts file
UniqueIntegrins <- IntInts[order(IntInts$A),]
UniqueIntegrins <- unique(UniqueIntegrins[c("A")])

#Modify UniqueIntegrins for downstream analysis 
UniqueIntegrins <- UniqueIntegrins %>%
  select(Gene_name = A) %>%
  mutate(Division = "Integrins",
         Category = "Integrins")


#Get Integrins from CDM_master file 
CDM_Integrins_ann <- merge(CDM_master, UniqueIntegrins, by = "Gene_name")


#Derive a full anootated CDM_list 
CDM_annotated <- rbind(CDM_annotated, CDM_Integrins_ann)

#Transform the Gene_names into 1 and 0 and calculate n + create consensus list
CDM_annotated[2:4] <- as.integer(!is.na(CDM_annotated[2:4]))
CDM_annotated["n"] <- 3 - apply(CDM_annotated[5:7], MARGIN = 1, FUN = function(x) length(x[is.na(x)]))

#Returns 1 if gene found in 3/4 datasets, otherwise return 0
CDM_annotated["Consensus_CDM"] <- lapply(CDM_annotated[11], function(x) ifelse(x>=2, 1, 0))

#Write Consensus CDM file
write.csv(CDM_annotated, file = "./output/HPDE_Consensus_CDM.csv", row.names = FALSE)


#2) Get Interactions with detected integrins and detected ECM molecules 
#Only use interactions nucleating from an Integrin alpha variant 
IntAnnotated <- IntInts %>% 
  filter(grepl("ITGA", A)) %>%
  select(Integrin = A, ECM_prot = B) 

#Combine Matrisome and Integrin file
MatItgSet <- rbind(Matrisome, UniqueIntegrins)

#Generate IntECMAnnotated which is the interaction of integrins only against matrisome proteins
IntAnnotated_ECM <- inner_join(IntAnnotated, Matrisome, by = c("ECM_prot"="Gene_name")) %>% distinct()

#Get the interactions to those matrisome proteins that are expressed 
Expressed_ECM_int_HPDE <- inner_join(IntAnnotated_ECM, CDM_annotated  %>% filter(Consensus_CDM == "1"), by = c("ECM_prot"="Gene_name")) %>% distinct()

#Interactions between identified integrins and identified ECM molecules 
Ident_interactions_HPDE <- inner_join(Expressed_ECM_int_HPDE, CDM_Integrins_ann %>% select(Gene_name), by = c("Integrin" = "Gene_name")) %>% distinct()

#Get the data for the CDM figure
Consensus_CDM <- CDM_annotated %>% filter(Consensus_CDM == "1")


#Get IDs for each object 
conv <- Consensus_CDM %>% 
  rownames_to_column("ID") %>%
  mutate(ID = paste0("ID", ID)) %>%
  select(ID, Gene_name)


Ident_interactions_f <- Ident_interactions_HPDE %>%
  full_join(conv, by = c("ECM_prot" = "Gene_name")) %>%
  left_join(conv, by = c("Integrin" = "Gene_name")) %>%
  mutate(Interaction = ifelse(is.na(Integrin), "", "pp")) 

Consensus_CDM_f <- inner_join(Consensus_CDM, conv, by = "Gene_name") %>% select(ID, Gene_name, Accession, Division, Category, Consensus_CDM)


#Save the files for input in Cytoscape 

write_csv(Consensus_CDM_f, "./output/1)_nodes_CDM_HPDE.csv", na = "")
write_csv(Ident_interactions_f, "./output/2)_edges_CDM_HPDE.csv", na = "")





####KPC1
#Do similar anlaysis with the KPC_1 CDM (load Masterfile here from "F_2020_SF7a-f_CDM")
CDM_KPC1 <- read_csv("./data/2020_SF7c_Annotated_KPC_CDM.csv") %>% 
  filter(Consensus_CDM == "1") %>%
  mutate(Gene_name_caps = str_to_upper(Gene_name))

#Get the interactions to those matrisome proteins that are expressed 
Expressed_ECM_int_KPC1 <- inner_join(IntAnnotated_ECM, CDM_KPC1  %>% filter(Consensus_CDM == "1"), by = c("ECM_prot"="Gene_name_caps")) %>% distinct()

#Interactions between identified integrins and identified ECM molecules 
Ident_interactions_KPC1 <- inner_join(Expressed_ECM_int_KPC1, CDM_KPC1 %>% 
                                        filter(Category == "Integrins") %>%
                                        select(Gene_name_caps), 
                                      by = c("Integrin" = "Gene_name_caps")) %>% distinct()


#Get IDs for each object 
conv_KPC1 <- CDM_KPC1 %>% 
  rownames_to_column("ID") %>%
  mutate(ID = paste0("ID", ID)) %>%
  select(ID, Gene_name)


Ident_interactions_KPC1_f <- Ident_interactions_KPC1 %>%
  full_join(conv_KPC1, by = c("ECM_prot" = "Gene_name"))
  
Consensus_CDM_KPC1_f <- inner_join(CDM_KPC1, conv_KPC1, by = "Gene_name") %>% select(ID, Gene_name, Accession, Division, Category, Consensus_CDM)

#Save consensus CDM to import in Cytoscape
write_csv(Consensus_CDM_KPC1_f, "./output/4)_nodes_KPC1_CDM.csv", na = "")


